Changes
=======

0.2.2 - August 27, 2014: Minor bugfixes including update of specutils version
        inclusion

0.2.1 - May 29, 2014 - bugfix release.  First to include CHANGES.  Intended to
        work when pip-installing

0.2 - first python-wrapped version?
